migrate

package
v0.0.0-...-bf2c6c7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2022 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// WithGlobalUniqueID sets the universal ids options to the migration.
	// If this option is enabled, ent migration will allocate a 1<<32 range
	// for the ids of each entity (table).
	// Note that this option cannot be applied on tables that already exist.
	WithGlobalUniqueID = schema.WithGlobalUniqueID
	// WithDropColumn sets the drop column option to the migration.
	// If this option is enabled, ent migration will drop old columns
	// that were used for both fields and edges. This defaults to false.
	WithDropColumn = schema.WithDropColumn
	// WithDropIndex sets the drop index option to the migration.
	// If this option is enabled, ent migration will drop old indexes
	// that were defined in the schema. This defaults to false.
	// Note that unique constraints are defined using `UNIQUE INDEX`,
	// and therefore, it's recommended to enable this option to get more
	// flexibility in the schema changes.
	WithDropIndex = schema.WithDropIndex
	// WithFixture sets the foreign-key renaming option to the migration when upgrading
	// ent from v0.1.0 (issue-#285). Defaults to false.
	WithFixture = schema.WithFixture
	// WithForeignKeys enables creating foreign-key in schema DDL. This defaults to true.
	WithForeignKeys = schema.WithForeignKeys
)
var (
	// AssetsColumns holds the columns for the "assets" table.
	AssetsColumns = []*schema.Column{
		{Name: "id", Type: field.TypeInt, Increment: true},
		{Name: "path", Type: field.TypeString},
		{Name: "ext", Type: field.TypeString},
		{Name: "type", Type: field.TypeString},
	}
	// AssetsTable holds the schema information for the "assets" table.
	AssetsTable = &schema.Table{
		Name:        "assets",
		Columns:     AssetsColumns,
		PrimaryKey:  []*schema.Column{AssetsColumns[0]},
		ForeignKeys: []*schema.ForeignKey{},
	}
	// DataSetsColumns holds the columns for the "data_sets" table.
	DataSetsColumns = []*schema.Column{
		{Name: "id", Type: field.TypeInt, Increment: true},
		{Name: "type", Type: field.TypeString, Size: 255},
		{Name: "title", Type: field.TypeString, Size: 2147483647},
		{Name: "config", Type: field.TypeString, Size: 2147483647},
		{Name: "view_block_dataset", Type: field.TypeInt, Nullable: true},
	}
	// DataSetsTable holds the schema information for the "data_sets" table.
	DataSetsTable = &schema.Table{
		Name:       "data_sets",
		Columns:    DataSetsColumns,
		PrimaryKey: []*schema.Column{DataSetsColumns[0]},
		ForeignKeys: []*schema.ForeignKey{
			{
				Symbol:     "data_sets_view_blocks_dataset",
				Columns:    []*schema.Column{DataSetsColumns[4]},
				RefColumns: []*schema.Column{ViewBlocksColumns[0]},
				OnDelete:   schema.SetNull,
			},
		},
	}
	// MenusColumns holds the columns for the "menus" table.
	MenusColumns = []*schema.Column{
		{Name: "id", Type: field.TypeInt, Increment: true},
		{Name: "title", Type: field.TypeString},
		{Name: "url", Type: field.TypeString},
		{Name: "created_at", Type: field.TypeTime},
		{Name: "updated_at", Type: field.TypeTime},
		{Name: "menu_children", Type: field.TypeInt, Nullable: true},
	}
	// MenusTable holds the schema information for the "menus" table.
	MenusTable = &schema.Table{
		Name:       "menus",
		Columns:    MenusColumns,
		PrimaryKey: []*schema.Column{MenusColumns[0]},
		ForeignKeys: []*schema.ForeignKey{
			{
				Symbol:     "menus_menus_children",
				Columns:    []*schema.Column{MenusColumns[5]},
				RefColumns: []*schema.Column{MenusColumns[0]},
				OnDelete:   schema.SetNull,
			},
		},
	}
	// SharesColumns holds the columns for the "shares" table.
	SharesColumns = []*schema.Column{
		{Name: "id", Type: field.TypeInt, Increment: true},
		{Name: "end_at", Type: field.TypeTime},
		{Name: "user_share", Type: field.TypeInt, Nullable: true},
		{Name: "view_share", Type: field.TypeInt, Nullable: true},
	}
	// SharesTable holds the schema information for the "shares" table.
	SharesTable = &schema.Table{
		Name:       "shares",
		Columns:    SharesColumns,
		PrimaryKey: []*schema.Column{SharesColumns[0]},
		ForeignKeys: []*schema.ForeignKey{
			{
				Symbol:     "shares_users_share",
				Columns:    []*schema.Column{SharesColumns[2]},
				RefColumns: []*schema.Column{UsersColumns[0]},
				OnDelete:   schema.SetNull,
			},
			{
				Symbol:     "shares_views_share",
				Columns:    []*schema.Column{SharesColumns[3]},
				RefColumns: []*schema.Column{ViewsColumns[0]},
				OnDelete:   schema.SetNull,
			},
		},
	}
	// TypeConfigsColumns holds the columns for the "type_configs" table.
	TypeConfigsColumns = []*schema.Column{
		{Name: "id", Type: field.TypeInt, Increment: true},
		{Name: "type", Type: field.TypeString, Size: 255},
		{Name: "title", Type: field.TypeString},
		{Name: "config", Type: field.TypeString, Size: 2147483647},
	}
	// TypeConfigsTable holds the schema information for the "type_configs" table.
	TypeConfigsTable = &schema.Table{
		Name:        "type_configs",
		Columns:     TypeConfigsColumns,
		PrimaryKey:  []*schema.Column{TypeConfigsColumns[0]},
		ForeignKeys: []*schema.ForeignKey{},
	}
	// UsersColumns holds the columns for the "users" table.
	UsersColumns = []*schema.Column{
		{Name: "id", Type: field.TypeInt, Increment: true},
		{Name: "username", Type: field.TypeString, Unique: true, Size: 255},
		{Name: "password", Type: field.TypeString, Size: 255},
		{Name: "enable", Type: field.TypeInt8},
	}
	// UsersTable holds the schema information for the "users" table.
	UsersTable = &schema.Table{
		Name:        "users",
		Columns:     UsersColumns,
		PrimaryKey:  []*schema.Column{UsersColumns[0]},
		ForeignKeys: []*schema.ForeignKey{},
	}
	// ViewsColumns holds the columns for the "views" table.
	ViewsColumns = []*schema.Column{
		{Name: "id", Type: field.TypeInt, Increment: true},
		{Name: "desc", Type: field.TypeString, Size: 255},
		{Name: "config", Type: field.TypeString, Size: 2147483647},
		{Name: "assets_view", Type: field.TypeInt, Nullable: true},
	}
	// ViewsTable holds the schema information for the "views" table.
	ViewsTable = &schema.Table{
		Name:       "views",
		Columns:    ViewsColumns,
		PrimaryKey: []*schema.Column{ViewsColumns[0]},
		ForeignKeys: []*schema.ForeignKey{
			{
				Symbol:     "views_assets_view",
				Columns:    []*schema.Column{ViewsColumns[3]},
				RefColumns: []*schema.Column{AssetsColumns[0]},
				OnDelete:   schema.SetNull,
			},
		},
	}
	// ViewBlocksColumns holds the columns for the "view_blocks" table.
	ViewBlocksColumns = []*schema.Column{
		{Name: "id", Type: field.TypeInt, Increment: true},
		{Name: "type", Type: field.TypeString, Size: 255},
		{Name: "config", Type: field.TypeString, Size: 2147483647},
		{Name: "view_blocks", Type: field.TypeInt, Nullable: true},
	}
	// ViewBlocksTable holds the schema information for the "view_blocks" table.
	ViewBlocksTable = &schema.Table{
		Name:       "view_blocks",
		Columns:    ViewBlocksColumns,
		PrimaryKey: []*schema.Column{ViewBlocksColumns[0]},
		ForeignKeys: []*schema.ForeignKey{
			{
				Symbol:     "view_blocks_views_blocks",
				Columns:    []*schema.Column{ViewBlocksColumns[3]},
				RefColumns: []*schema.Column{ViewsColumns[0]},
				OnDelete:   schema.SetNull,
			},
		},
	}
	// Tables holds all the tables in the schema.
	Tables = []*schema.Table{
		AssetsTable,
		DataSetsTable,
		MenusTable,
		SharesTable,
		TypeConfigsTable,
		UsersTable,
		ViewsTable,
		ViewBlocksTable,
	}
)

Functions

This section is empty.

Types

type Schema

type Schema struct {
	// contains filtered or unexported fields
}

Schema is the API for creating, migrating and dropping a schema.

func NewSchema

func NewSchema(drv dialect.Driver) *Schema

NewSchema creates a new schema client.

func (*Schema) Create

func (s *Schema) Create(ctx context.Context, opts ...schema.MigrateOption) error

Create creates all schema resources.

func (*Schema) WriteTo

func (s *Schema) WriteTo(ctx context.Context, w io.Writer, opts ...schema.MigrateOption) error

WriteTo writes the schema changes to w instead of running them against the database.

if err := client.Schema.WriteTo(context.Background(), os.Stdout); err != nil {
	log.Fatal(err)
}

Jump to