viewblock

package
v0.0.0-...-bf2c6c7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2022 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the viewblock type in the database.
	Label = "view_block"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldType holds the string denoting the type field in the database.
	FieldType = "type"
	// FieldConfig holds the string denoting the config field in the database.
	FieldConfig = "config"
	// EdgeView holds the string denoting the view edge name in mutations.
	EdgeView = "view"
	// EdgeDataset holds the string denoting the dataset edge name in mutations.
	EdgeDataset = "dataset"
	// Table holds the table name of the viewblock in the database.
	Table = "view_blocks"
	// ViewTable is the table the holds the view relation/edge.
	ViewTable = "view_blocks"
	// ViewInverseTable is the table name for the View entity.
	// It exists in this package in order to avoid circular dependency with the "view" package.
	ViewInverseTable = "views"
	// ViewColumn is the table column denoting the view relation/edge.
	ViewColumn = "view_blocks"
	// DatasetTable is the table the holds the dataset relation/edge.
	DatasetTable = "data_sets"
	// DatasetInverseTable is the table name for the DataSet entity.
	// It exists in this package in order to avoid circular dependency with the "dataset" package.
	DatasetInverseTable = "data_sets"
	// DatasetColumn is the table column denoting the dataset relation/edge.
	DatasetColumn = "view_block_dataset"
)

Variables

Columns holds all SQL columns for viewblock fields.

var ForeignKeys = []string{
	"view_blocks",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "view_blocks" table and are not defined as standalone fields in the schema.

var (
	// TypeValidator is a validator for the "type" field. It is called by the builders before save.
	TypeValidator func(string) error
)

Functions

func And

func And(predicates ...predicate.ViewBlock) predicate.ViewBlock

And groups predicates with the AND operator between them.

func Config

func Config(v string) predicate.ViewBlock

Config applies equality check predicate on the "config" field. It's identical to ConfigEQ.

func ConfigContains

func ConfigContains(v string) predicate.ViewBlock

ConfigContains applies the Contains predicate on the "config" field.

func ConfigContainsFold

func ConfigContainsFold(v string) predicate.ViewBlock

ConfigContainsFold applies the ContainsFold predicate on the "config" field.

func ConfigEQ

func ConfigEQ(v string) predicate.ViewBlock

ConfigEQ applies the EQ predicate on the "config" field.

func ConfigEqualFold

func ConfigEqualFold(v string) predicate.ViewBlock

ConfigEqualFold applies the EqualFold predicate on the "config" field.

func ConfigGT

func ConfigGT(v string) predicate.ViewBlock

ConfigGT applies the GT predicate on the "config" field.

func ConfigGTE

func ConfigGTE(v string) predicate.ViewBlock

ConfigGTE applies the GTE predicate on the "config" field.

func ConfigHasPrefix

func ConfigHasPrefix(v string) predicate.ViewBlock

ConfigHasPrefix applies the HasPrefix predicate on the "config" field.

func ConfigHasSuffix

func ConfigHasSuffix(v string) predicate.ViewBlock

ConfigHasSuffix applies the HasSuffix predicate on the "config" field.

func ConfigIn

func ConfigIn(vs ...string) predicate.ViewBlock

ConfigIn applies the In predicate on the "config" field.

func ConfigLT

func ConfigLT(v string) predicate.ViewBlock

ConfigLT applies the LT predicate on the "config" field.

func ConfigLTE

func ConfigLTE(v string) predicate.ViewBlock

ConfigLTE applies the LTE predicate on the "config" field.

func ConfigNEQ

func ConfigNEQ(v string) predicate.ViewBlock

ConfigNEQ applies the NEQ predicate on the "config" field.

func ConfigNotIn

func ConfigNotIn(vs ...string) predicate.ViewBlock

ConfigNotIn applies the NotIn predicate on the "config" field.

func HasDataset

func HasDataset() predicate.ViewBlock

HasDataset applies the HasEdge predicate on the "dataset" edge.

func HasDatasetWith

func HasDatasetWith(preds ...predicate.DataSet) predicate.ViewBlock

HasDatasetWith applies the HasEdge predicate on the "dataset" edge with a given conditions (other predicates).

func HasView

func HasView() predicate.ViewBlock

HasView applies the HasEdge predicate on the "view" edge.

func HasViewWith

func HasViewWith(preds ...predicate.View) predicate.ViewBlock

HasViewWith applies the HasEdge predicate on the "view" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.ViewBlock

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.ViewBlock

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.ViewBlock

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.ViewBlock

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.ViewBlock

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.ViewBlock

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.ViewBlock

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.ViewBlock

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.ViewBlock

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.ViewBlock) predicate.ViewBlock

Or groups predicates with the OR operator between them.

func Type

func Type(v string) predicate.ViewBlock

Type applies equality check predicate on the "type" field. It's identical to TypeEQ.

func TypeContains

func TypeContains(v string) predicate.ViewBlock

TypeContains applies the Contains predicate on the "type" field.

func TypeContainsFold

func TypeContainsFold(v string) predicate.ViewBlock

TypeContainsFold applies the ContainsFold predicate on the "type" field.

func TypeEQ

func TypeEQ(v string) predicate.ViewBlock

TypeEQ applies the EQ predicate on the "type" field.

func TypeEqualFold

func TypeEqualFold(v string) predicate.ViewBlock

TypeEqualFold applies the EqualFold predicate on the "type" field.

func TypeGT

func TypeGT(v string) predicate.ViewBlock

TypeGT applies the GT predicate on the "type" field.

func TypeGTE

func TypeGTE(v string) predicate.ViewBlock

TypeGTE applies the GTE predicate on the "type" field.

func TypeHasPrefix

func TypeHasPrefix(v string) predicate.ViewBlock

TypeHasPrefix applies the HasPrefix predicate on the "type" field.

func TypeHasSuffix

func TypeHasSuffix(v string) predicate.ViewBlock

TypeHasSuffix applies the HasSuffix predicate on the "type" field.

func TypeIn

func TypeIn(vs ...string) predicate.ViewBlock

TypeIn applies the In predicate on the "type" field.

func TypeLT

func TypeLT(v string) predicate.ViewBlock

TypeLT applies the LT predicate on the "type" field.

func TypeLTE

func TypeLTE(v string) predicate.ViewBlock

TypeLTE applies the LTE predicate on the "type" field.

func TypeNEQ

func TypeNEQ(v string) predicate.ViewBlock

TypeNEQ applies the NEQ predicate on the "type" field.

func TypeNotIn

func TypeNotIn(vs ...string) predicate.ViewBlock

TypeNotIn applies the NotIn predicate on the "type" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

This section is empty.

Jump to