Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.TypeConfig) predicate.TypeConfig
- func Config(v string) predicate.TypeConfig
- func ConfigContains(v string) predicate.TypeConfig
- func ConfigContainsFold(v string) predicate.TypeConfig
- func ConfigEQ(v string) predicate.TypeConfig
- func ConfigEqualFold(v string) predicate.TypeConfig
- func ConfigGT(v string) predicate.TypeConfig
- func ConfigGTE(v string) predicate.TypeConfig
- func ConfigHasPrefix(v string) predicate.TypeConfig
- func ConfigHasSuffix(v string) predicate.TypeConfig
- func ConfigIn(vs ...string) predicate.TypeConfig
- func ConfigLT(v string) predicate.TypeConfig
- func ConfigLTE(v string) predicate.TypeConfig
- func ConfigNEQ(v string) predicate.TypeConfig
- func ConfigNotIn(vs ...string) predicate.TypeConfig
- func ID(id int) predicate.TypeConfig
- func IDEQ(id int) predicate.TypeConfig
- func IDGT(id int) predicate.TypeConfig
- func IDGTE(id int) predicate.TypeConfig
- func IDIn(ids ...int) predicate.TypeConfig
- func IDLT(id int) predicate.TypeConfig
- func IDLTE(id int) predicate.TypeConfig
- func IDNEQ(id int) predicate.TypeConfig
- func IDNotIn(ids ...int) predicate.TypeConfig
- func Not(p predicate.TypeConfig) predicate.TypeConfig
- func Or(predicates ...predicate.TypeConfig) predicate.TypeConfig
- func Title(v string) predicate.TypeConfig
- func TitleContains(v string) predicate.TypeConfig
- func TitleContainsFold(v string) predicate.TypeConfig
- func TitleEQ(v string) predicate.TypeConfig
- func TitleEqualFold(v string) predicate.TypeConfig
- func TitleGT(v string) predicate.TypeConfig
- func TitleGTE(v string) predicate.TypeConfig
- func TitleHasPrefix(v string) predicate.TypeConfig
- func TitleHasSuffix(v string) predicate.TypeConfig
- func TitleIn(vs ...string) predicate.TypeConfig
- func TitleLT(v string) predicate.TypeConfig
- func TitleLTE(v string) predicate.TypeConfig
- func TitleNEQ(v string) predicate.TypeConfig
- func TitleNotIn(vs ...string) predicate.TypeConfig
- func Type(v string) predicate.TypeConfig
- func TypeContains(v string) predicate.TypeConfig
- func TypeContainsFold(v string) predicate.TypeConfig
- func TypeEQ(v string) predicate.TypeConfig
- func TypeEqualFold(v string) predicate.TypeConfig
- func TypeGT(v string) predicate.TypeConfig
- func TypeGTE(v string) predicate.TypeConfig
- func TypeHasPrefix(v string) predicate.TypeConfig
- func TypeHasSuffix(v string) predicate.TypeConfig
- func TypeIn(vs ...string) predicate.TypeConfig
- func TypeLT(v string) predicate.TypeConfig
- func TypeLTE(v string) predicate.TypeConfig
- func TypeNEQ(v string) predicate.TypeConfig
- func TypeNotIn(vs ...string) predicate.TypeConfig
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the typeconfig type in the database. Label = "type_config" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldType holds the string denoting the type field in the database. FieldType = "type" // FieldTitle holds the string denoting the title field in the database. FieldTitle = "title" // FieldConfig holds the string denoting the config field in the database. FieldConfig = "config" // Table holds the table name of the typeconfig in the database. Table = "type_configs" )
Variables ¶
var Columns = []string{ FieldID, FieldType, FieldTitle, FieldConfig, }
Columns holds all SQL columns for typeconfig fields.
var ( // TypeValidator is a validator for the "type" field. It is called by the builders before save. TypeValidator func(string) error )
Functions ¶
func And ¶
func And(predicates ...predicate.TypeConfig) predicate.TypeConfig
And groups predicates with the AND operator between them.
func Config ¶
func Config(v string) predicate.TypeConfig
Config applies equality check predicate on the "config" field. It's identical to ConfigEQ.
func ConfigContains ¶
func ConfigContains(v string) predicate.TypeConfig
ConfigContains applies the Contains predicate on the "config" field.
func ConfigContainsFold ¶
func ConfigContainsFold(v string) predicate.TypeConfig
ConfigContainsFold applies the ContainsFold predicate on the "config" field.
func ConfigEQ ¶
func ConfigEQ(v string) predicate.TypeConfig
ConfigEQ applies the EQ predicate on the "config" field.
func ConfigEqualFold ¶
func ConfigEqualFold(v string) predicate.TypeConfig
ConfigEqualFold applies the EqualFold predicate on the "config" field.
func ConfigGT ¶
func ConfigGT(v string) predicate.TypeConfig
ConfigGT applies the GT predicate on the "config" field.
func ConfigGTE ¶
func ConfigGTE(v string) predicate.TypeConfig
ConfigGTE applies the GTE predicate on the "config" field.
func ConfigHasPrefix ¶
func ConfigHasPrefix(v string) predicate.TypeConfig
ConfigHasPrefix applies the HasPrefix predicate on the "config" field.
func ConfigHasSuffix ¶
func ConfigHasSuffix(v string) predicate.TypeConfig
ConfigHasSuffix applies the HasSuffix predicate on the "config" field.
func ConfigIn ¶
func ConfigIn(vs ...string) predicate.TypeConfig
ConfigIn applies the In predicate on the "config" field.
func ConfigLT ¶
func ConfigLT(v string) predicate.TypeConfig
ConfigLT applies the LT predicate on the "config" field.
func ConfigLTE ¶
func ConfigLTE(v string) predicate.TypeConfig
ConfigLTE applies the LTE predicate on the "config" field.
func ConfigNEQ ¶
func ConfigNEQ(v string) predicate.TypeConfig
ConfigNEQ applies the NEQ predicate on the "config" field.
func ConfigNotIn ¶
func ConfigNotIn(vs ...string) predicate.TypeConfig
ConfigNotIn applies the NotIn predicate on the "config" field.
func IDGTE ¶
func IDGTE(id int) predicate.TypeConfig
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.TypeConfig
IDIn applies the In predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.TypeConfig
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.TypeConfig
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.TypeConfig
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.TypeConfig) predicate.TypeConfig
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.TypeConfig) predicate.TypeConfig
Or groups predicates with the OR operator between them.
func Title ¶
func Title(v string) predicate.TypeConfig
Title applies equality check predicate on the "title" field. It's identical to TitleEQ.
func TitleContains ¶
func TitleContains(v string) predicate.TypeConfig
TitleContains applies the Contains predicate on the "title" field.
func TitleContainsFold ¶
func TitleContainsFold(v string) predicate.TypeConfig
TitleContainsFold applies the ContainsFold predicate on the "title" field.
func TitleEQ ¶
func TitleEQ(v string) predicate.TypeConfig
TitleEQ applies the EQ predicate on the "title" field.
func TitleEqualFold ¶
func TitleEqualFold(v string) predicate.TypeConfig
TitleEqualFold applies the EqualFold predicate on the "title" field.
func TitleGT ¶
func TitleGT(v string) predicate.TypeConfig
TitleGT applies the GT predicate on the "title" field.
func TitleGTE ¶
func TitleGTE(v string) predicate.TypeConfig
TitleGTE applies the GTE predicate on the "title" field.
func TitleHasPrefix ¶
func TitleHasPrefix(v string) predicate.TypeConfig
TitleHasPrefix applies the HasPrefix predicate on the "title" field.
func TitleHasSuffix ¶
func TitleHasSuffix(v string) predicate.TypeConfig
TitleHasSuffix applies the HasSuffix predicate on the "title" field.
func TitleIn ¶
func TitleIn(vs ...string) predicate.TypeConfig
TitleIn applies the In predicate on the "title" field.
func TitleLT ¶
func TitleLT(v string) predicate.TypeConfig
TitleLT applies the LT predicate on the "title" field.
func TitleLTE ¶
func TitleLTE(v string) predicate.TypeConfig
TitleLTE applies the LTE predicate on the "title" field.
func TitleNEQ ¶
func TitleNEQ(v string) predicate.TypeConfig
TitleNEQ applies the NEQ predicate on the "title" field.
func TitleNotIn ¶
func TitleNotIn(vs ...string) predicate.TypeConfig
TitleNotIn applies the NotIn predicate on the "title" field.
func Type ¶
func Type(v string) predicate.TypeConfig
Type applies equality check predicate on the "type" field. It's identical to TypeEQ.
func TypeContains ¶
func TypeContains(v string) predicate.TypeConfig
TypeContains applies the Contains predicate on the "type" field.
func TypeContainsFold ¶
func TypeContainsFold(v string) predicate.TypeConfig
TypeContainsFold applies the ContainsFold predicate on the "type" field.
func TypeEQ ¶
func TypeEQ(v string) predicate.TypeConfig
TypeEQ applies the EQ predicate on the "type" field.
func TypeEqualFold ¶
func TypeEqualFold(v string) predicate.TypeConfig
TypeEqualFold applies the EqualFold predicate on the "type" field.
func TypeGT ¶
func TypeGT(v string) predicate.TypeConfig
TypeGT applies the GT predicate on the "type" field.
func TypeGTE ¶
func TypeGTE(v string) predicate.TypeConfig
TypeGTE applies the GTE predicate on the "type" field.
func TypeHasPrefix ¶
func TypeHasPrefix(v string) predicate.TypeConfig
TypeHasPrefix applies the HasPrefix predicate on the "type" field.
func TypeHasSuffix ¶
func TypeHasSuffix(v string) predicate.TypeConfig
TypeHasSuffix applies the HasSuffix predicate on the "type" field.
func TypeIn ¶
func TypeIn(vs ...string) predicate.TypeConfig
TypeIn applies the In predicate on the "type" field.
func TypeLT ¶
func TypeLT(v string) predicate.TypeConfig
TypeLT applies the LT predicate on the "type" field.
func TypeLTE ¶
func TypeLTE(v string) predicate.TypeConfig
TypeLTE applies the LTE predicate on the "type" field.
func TypeNEQ ¶
func TypeNEQ(v string) predicate.TypeConfig
TypeNEQ applies the NEQ predicate on the "type" field.
func TypeNotIn ¶
func TypeNotIn(vs ...string) predicate.TypeConfig
TypeNotIn applies the NotIn predicate on the "type" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.