Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.ViewBlock) predicate.ViewBlock
- func Config(v string) predicate.ViewBlock
- func ConfigContains(v string) predicate.ViewBlock
- func ConfigContainsFold(v string) predicate.ViewBlock
- func ConfigEQ(v string) predicate.ViewBlock
- func ConfigEqualFold(v string) predicate.ViewBlock
- func ConfigGT(v string) predicate.ViewBlock
- func ConfigGTE(v string) predicate.ViewBlock
- func ConfigHasPrefix(v string) predicate.ViewBlock
- func ConfigHasSuffix(v string) predicate.ViewBlock
- func ConfigIn(vs ...string) predicate.ViewBlock
- func ConfigLT(v string) predicate.ViewBlock
- func ConfigLTE(v string) predicate.ViewBlock
- func ConfigNEQ(v string) predicate.ViewBlock
- func ConfigNotIn(vs ...string) predicate.ViewBlock
- func HasDataset() predicate.ViewBlock
- func HasDatasetWith(preds ...predicate.DataSet) predicate.ViewBlock
- func HasView() predicate.ViewBlock
- func HasViewWith(preds ...predicate.View) predicate.ViewBlock
- func ID(id int) predicate.ViewBlock
- func IDEQ(id int) predicate.ViewBlock
- func IDGT(id int) predicate.ViewBlock
- func IDGTE(id int) predicate.ViewBlock
- func IDIn(ids ...int) predicate.ViewBlock
- func IDLT(id int) predicate.ViewBlock
- func IDLTE(id int) predicate.ViewBlock
- func IDNEQ(id int) predicate.ViewBlock
- func IDNotIn(ids ...int) predicate.ViewBlock
- func Not(p predicate.ViewBlock) predicate.ViewBlock
- func Or(predicates ...predicate.ViewBlock) predicate.ViewBlock
- func Type(v string) predicate.ViewBlock
- func TypeContains(v string) predicate.ViewBlock
- func TypeContainsFold(v string) predicate.ViewBlock
- func TypeEQ(v string) predicate.ViewBlock
- func TypeEqualFold(v string) predicate.ViewBlock
- func TypeGT(v string) predicate.ViewBlock
- func TypeGTE(v string) predicate.ViewBlock
- func TypeHasPrefix(v string) predicate.ViewBlock
- func TypeHasSuffix(v string) predicate.ViewBlock
- func TypeIn(vs ...string) predicate.ViewBlock
- func TypeLT(v string) predicate.ViewBlock
- func TypeLTE(v string) predicate.ViewBlock
- func TypeNEQ(v string) predicate.ViewBlock
- func TypeNotIn(vs ...string) predicate.ViewBlock
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the viewblock type in the database. Label = "view_block" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldType holds the string denoting the type field in the database. FieldType = "type" // FieldConfig holds the string denoting the config field in the database. FieldConfig = "config" // EdgeView holds the string denoting the view edge name in mutations. EdgeView = "view" // EdgeDataset holds the string denoting the dataset edge name in mutations. EdgeDataset = "dataset" // Table holds the table name of the viewblock in the database. Table = "view_blocks" // ViewTable is the table the holds the view relation/edge. ViewTable = "view_blocks" // ViewInverseTable is the table name for the View entity. // It exists in this package in order to avoid circular dependency with the "view" package. ViewInverseTable = "views" // ViewColumn is the table column denoting the view relation/edge. ViewColumn = "view_blocks" // DatasetTable is the table the holds the dataset relation/edge. DatasetTable = "data_sets" // DatasetInverseTable is the table name for the DataSet entity. // It exists in this package in order to avoid circular dependency with the "dataset" package. DatasetInverseTable = "data_sets" // DatasetColumn is the table column denoting the dataset relation/edge. DatasetColumn = "view_block_dataset" )
Variables ¶
var Columns = []string{ FieldID, FieldType, FieldConfig, }
Columns holds all SQL columns for viewblock fields.
var ForeignKeys = []string{
"view_blocks",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "view_blocks" table and are not defined as standalone fields in the schema.
var ( // TypeValidator is a validator for the "type" field. It is called by the builders before save. TypeValidator func(string) error )
Functions ¶
func Config ¶
Config applies equality check predicate on the "config" field. It's identical to ConfigEQ.
func ConfigContains ¶
ConfigContains applies the Contains predicate on the "config" field.
func ConfigContainsFold ¶
ConfigContainsFold applies the ContainsFold predicate on the "config" field.
func ConfigEqualFold ¶
ConfigEqualFold applies the EqualFold predicate on the "config" field.
func ConfigHasPrefix ¶
ConfigHasPrefix applies the HasPrefix predicate on the "config" field.
func ConfigHasSuffix ¶
ConfigHasSuffix applies the HasSuffix predicate on the "config" field.
func ConfigNotIn ¶
ConfigNotIn applies the NotIn predicate on the "config" field.
func HasDataset ¶
HasDataset applies the HasEdge predicate on the "dataset" edge.
func HasDatasetWith ¶
HasDatasetWith applies the HasEdge predicate on the "dataset" edge with a given conditions (other predicates).
func HasViewWith ¶
HasViewWith applies the HasEdge predicate on the "view" edge with a given conditions (other predicates).
func TypeContains ¶
TypeContains applies the Contains predicate on the "type" field.
func TypeContainsFold ¶
TypeContainsFold applies the ContainsFold predicate on the "type" field.
func TypeEqualFold ¶
TypeEqualFold applies the EqualFold predicate on the "type" field.
func TypeHasPrefix ¶
TypeHasPrefix applies the HasPrefix predicate on the "type" field.
func TypeHasSuffix ¶
TypeHasSuffix applies the HasSuffix predicate on the "type" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.